@@ -442,8 +442,9 @@ instance Monad Parser where
 
   (>>) = (*>)
 
-  -- @fail message@ does just that - fails with a /message/.
-  fail message = Parser $ \state -> failReply state message
+-- | @fail message@ does just that - fails with a /message/.
+pfail :: String -> Parser a
+pfail message = Parser $ \state -> failReply state message
 
 -- ** Parsing operators
 --
@@ -491,7 +492,7 @@ parser % n
 -- | @parser <% n@ matches fewer than /n/ occurrences of /parser/.
 (<%) :: (Match match result) => match -> Int -> Pattern
 parser <% n
-  | n < 1 = fail "Fewer than 0 repetitions"
+  | n < 1 = pfail "Fewer than 0 repetitions"
   | n == 1 = reject parser Nothing
   | n > 1  = DeLess ^ ( ((parser ! DeLess) *> (parser <% n .- 1)) <|> empty )
 
@@ -577,7 +578,7 @@ first / second = Parser $ applyParser (match first <|> match second)
 -- | @first <|> second@ tries to parse /first/, and failing that parses
 -- /second/, unless /first/ has committed in which case is fails immediately.
 instance Alternative Parser where
-  empty = fail "empty"
+  empty = pfail "empty"
 
   left <|> right = Parser $ \state -> decideParser state D.empty left right state
     where
@@ -897,7 +898,7 @@ prefixErrorWith pattern prefix =
     in case reply^.rResult of
          Result _       -> reply
          More more      -> reply { rResult = More $ prefixErrorWith more prefix }
-         Failed message -> reply { rResult = More $ prefix & (fail message :: Parser result) }
+         Failed message -> reply { rResult = More $ prefix & (pfail message :: Parser result) }
 
 -- * Production parameters
 
@@ -1406,18 +1407,19 @@ nb_single_multi_line n  {- 125 -} = nb_ns_single_in_line
 -- 7.3.3 Plain Style
 
 ns_plain_first _c  {- 126 -} = ns_char - c_indicator
-                            / ( ':' / '?' / '-' ) & ( ns_char >?)
+                            / ( ':' / '?' / '-' ) & ( (ns_plain_safe _c) >?)
 
 ns_plain_safe c   {- 127 -} = case c of
                                    FlowOut  -> ns_plain_safe_out
                                    FlowIn   -> ns_plain_safe_in
                                    BlockKey -> ns_plain_safe_out
                                    FlowKey  -> ns_plain_safe_in
-ns_plain_safe_out {- 128 -} = ns_char - c_mapping_value - c_comment
-ns_plain_safe_in  {- 129 -} = ns_plain_safe_out - c_flow_indicator
-ns_plain_char c   {- 130 -} = ns_plain_safe c
+                                   
+ns_plain_safe_out {- 128 -} = ns_char
+ns_plain_safe_in  {- 129 -} = ns_char - c_flow_indicator
+ns_plain_char c   {- 130 -} = ns_plain_safe c - ':' - '#'
                             / ( ns_char <?) & '#'
-                            / ':' & ( ns_char >?)
+                            / ':' & ( (ns_plain_safe c) >?)
 
 ns_plain n c          {- 131 -} = wrapTokens BeginScalar EndScalar
                                 $ text (case c of
@@ -1481,7 +1483,7 @@ ns_flow_map_yaml_key_entry n c {- 145 -}    = ( DeNode ^ ns_flow_yaml_node n c )
 c_ns_flow_map_empty_key_entry n c {- 146 -} = e_node
                                             & c_ns_flow_map_separate_value n c
 
-c_ns_flow_map_separate_value n c {- 147 -}  = c_mapping_value & ( ns_char >!) ! DePair
+c_ns_flow_map_separate_value n c {- 147 -}  = c_mapping_value & ( (ns_plain_safe c) >!) ! DePair
                                             & ( ( s_separate n c & ns_flow_node n c )
                                               / e_node )
 
@@ -1667,8 +1669,8 @@ ns_l_block_map_entry n {- 188 -} = wrapTokens BeginPair EndPair
                                  / ns_l_block_map_implicit_entry n
 c_l_block_map_explicit_entry n {- 189 -} = c_l_block_map_explicit_key n
                                          & ( l_block_map_explicit_value n
-                                         / e_node )
-c_l_block_map_explicit_key n   {- 190 -} = c_mapping_key ! DeNode & s_l__block_indented n BlockOut
+                                         / e_node )                                         
+c_l_block_map_explicit_key n   {- 190 -} = c_mapping_key & ( ns_char >!) ! DeNode & s_l__block_indented n BlockOut
 l_block_map_explicit_value n   {- 191 -} = s_indent n & c_mapping_value & s_l__block_indented n BlockOut
 
 ns_l_block_map_implicit_entry n {- 192 -} = ( ns_s_block_map_implicit_key
